@@ -258,13 +258,21 @@ fn query_fk(connection: &Connection, table_name: &str) -> Vec<ForeignKey> {
             id: row.get(0).unwrap(),
             table,
             from_column: vec![own_columns
-                .into_iter()
-                .find(|c| c.name.to_lowercase() == to_column.to_lowercase())
-                .unwrap()],
-            to_column: vec![other_table_columns
                 .clone()
                 .into_iter()
                 .find(|c| c.name.to_lowercase() == from_column.to_lowercase())
+                .expect(&format!(
+                    "Expected to find {} in {:#?}",
+                    from_column.to_lowercase(),
+                    own_columns
+                        .iter()
+                        .map(|c| c.name.to_lowercase())
+                        .collect::<Vec<_>>()
+                ))],
+            to_column: vec![other_table_columns
+                .clone()
+                .into_iter()
+                .find(|c| c.name.to_lowercase() == to_column.to_lowercase())
                 .unwrap()],
         };
 
